@@ -20,15 +20,15 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gtkNew.ml 1347 2007-06-20 07:40:34Z guesdon $ *)
+(* $Id$ *)
 
 open StdLabels
 open Gtk
 
 type t
 
-(* if you modify this type modify widget_info_array 
-   in ml_gtk.c in accordance *)
+(* if you modify this type modify widget_info_array
+   in ml_gtknew.c in accordance *)
 type object_type =
   | OBJECT  | WIDGET  | MISC  | LABEL  | ACCELLABEL  | TIPSQUERY  | ARROW
   | IMAGE   | PIXMAP  | CONTAINER  | BIN  | ALIGNMENT  | FRAME  | ASPECTFRAME
@@ -38,7 +38,8 @@ type object_type =
   | INPUTDIALOG  | FILESELECTION  | FONTSELECTIONDIALOG  | PLUG
   | EVENTBOX  | HANDLEBOX  | SCROLLEDWINDOW  | VIEWPORT  | BOX
   | BUTTONBOX  | HBUTTONBOX  | VBUTTONBOX  | VBOX  | COLORSELECTION
-  | GAMMACURVE  | HBOX  | COMBO  | STATUSBAR  | CLIST  | CTREE  | FIXED
+  | GAMMACURVE  | HBOX  | COMBO  | STATUSBAR  | STATUSICON
+  | CLIST  | CTREE  | FIXED
   | NOTEBOOK  | FONTSELECTION  | PANED  | HPANED  | VPANED  | LAYOUT
   | LIST  | MENUSHELL  | MENUBAR  | MENU  | PACKER  | SOCKET  | TABLE
   | TOOLBAR  | TREE  | CALENDAR  | DRAWINGAREA  | CURVE  | EDITABLE
